smartcard.Card.Card

# ``smartcard`.`Card`.`Card``

class documentation

`class Card(object):`

View In Hierarchy

Card class.

Method | `__eq__` | Return True if self==other (same reader and same atr). Return False otherwise.
Method | `__hash__` | Returns a hash value for this object (str(self) is unique).
Method | `__init__` | Card constructor.
Method | `__ne__` | Return True if self!=other (same reader and same atr).Returns False otherwise.
Method | `__repr__` | Return a string representing the Card (atr and reader concatenation).
Method | `createConnection` | Return a CardConnection to the Card object.
Instance Variable | `atr` | Undocumented
Instance Variable | `reader` | Undocumented

def __eq__(self, other):

Return True if self==other (same reader and same atr). Return False otherwise.

def __hash__(self):

Returns a hash value for this object (str(self) is unique).

def __init__(self, reader, atr):

Card constructor.

Parameters
reader | reader in which the card is inserted
atr | ATR of the card

def __ne__(self, other):

Return True if self!=other (same reader and same atr).Returns False otherwise.

def __repr__(self):

Return a string representing the Card (atr and reader concatenation).

def createConnection(self):

Return a CardConnection to the Card object.

atr =

Undocumented

reader =

Undocumented